@@ -6,7 +6,6 @@ from invenio_indexer.api import RecordIndexer
 from invenio_pidstore.providers.recordid import RecordIdProvider
 from invenio_records.api import Record
 from invenio_records_rest.utils import allow_all
-from oarepo_actions.decorators import action
 from oarepo_communities.record import CommunityRecordMixin
 from oarepo_fsm.mixins import FSMMixin
 from oarepo_validate import MarshmallowValidatedRecordMixin, SchemaKeepingRecordMixin
@@ -17,7 +16,7 @@ from .marshmallow import SampleSchemaV1
 
 class SampleRecord(SchemaKeepingRecordMixin,
                    MarshmallowValidatedRecordMixin,
-                   CommunityRecordMixin, FSMMixin,
+                   #CommunityRecordMixin, FSMMixin,
                    Record):
     ALLOWED_SCHEMAS = SAMPLE_ALLOWED_SCHEMAS
     PREFERRED_SCHEMA = SAMPLE_PREFERRED_SCHEMA
